==> haskell-cryptohash-cryptoapi-0.1.4-258-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-HybX8TixvD766M0EFWZmmf
key:                  cryptohash-cryptoapi-0.1.4-HybX8TixvD766M0EFWZmmf
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  0fbf0ee3f26cd9633be87e12bf7221a7
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-cryptoapi
hs-libraries:         HScryptohash-cryptoapi-0.1.4-HybX8TixvD766M0EFWZmmf
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-H2rQjLwJg166An3m7THxYG
    cryptonite-0.30-6t1O7psLMh7IeVK47IhUa0
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptohash-cryptoapi-0.1.4-265-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptohash-cryptoapi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptohash-cryptoapi
version:              0.1.4
visibility:           public
id:                   cryptohash-cryptoapi-0.1.4-HE7ihAtF1qZEt4O2F03uXi
key:                  cryptohash-cryptoapi-0.1.4-HE7ihAtF1qZEt4O2F03uXi
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
homepage:             https://github.com/vincenthz/hs-cryptohash-cryptoapi
synopsis:             Crypto-api interfaces for cryptohash
description:          Crypto-api interfaces for cryptohash
category:             Cryptography
abi:                  563f87d0752bce59806218334ac50339
exposed:              True
exposed-modules:      Crypto.Hash.CryptoAPI
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cryptohash-cryptoapi-0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptohash-cryptoapi
hs-libraries:         HScryptohash-cryptoapi-0.1.4-HE7ihAtF1qZEt4O2F03uXi
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    cereal-0.5.8.3-KCibhvvTsuv86wVgcPkD6
    crypto-api-0.13.3-H2rQjLwJg166An3m7THxYG
    cryptonite-0.30-ATVl7QapHZS9RRZ445MyBy
    memory-0.17.0-3DbDQrj54CLAPAnWUJBJ4b
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:
    /usr/share/doc/haskell-cryptohash-cryptoapi/html/cryptohash-cryptoapi.haddock

haddock-html:         /usr/share/doc/haskell-cryptohash-cryptoapi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
